@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CGIResponse.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: CGIResponse.h 2508 2007-07-06 22:47:18Z svn $
  *****************************************************************************/
 
 #ifndef CGI_RESPONSE_H
@@ -66,85 +66,49 @@ public:
 
     static const char *get_request_uri(Handle *r)
     {
-        char *uri;
-
-        if (apr_env_get(&uri, "REQUEST_URI", r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
-        }
-
-        return uri;
+        return get_env(r->pool, "REQUEST_URI");
     };
     static const char *get_content_type(Handle *r)
     {
-        char *content_type;
-
-        if (apr_env_get(&content_type, "Content-Type",
-                        r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
-        }
-
-        return content_type;
+        return get_env(r->pool, "CONTENT_TYPE");
     };
     static apr_size_t get_content_size(Handle *r)
     {
-        char *content_size;
-
-        if (apr_env_get(&content_size, "Content-Length",
-                        r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
-        }
-
-        return static_cast<apr_size_t>(apr_atoi64(content_size));
+        return static_cast<apr_size_t>(apr_atoi64(get_env(r->pool,
+                                                         "CONTENT_LENGTH")));
     };
     static const char *get_query(Handle *r)
     {
-        char *query;
-
-        if (apr_env_get(&query, "QUERY_STRING", r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
-        }
-
-        return query;
+        return get_env(r->pool, "QUERY_STRING");
     };
     static const char *get_remote_ip(Handle *r)
     {
-        char *remote_ip;
+        return get_env(r->pool, "REMOTE_ADDR");
+    };
+    static apr_sockaddr_t *get_remote_addr(Handle *r)
+    {
+        apr_sockaddr_t *sockaddr;
 
-        if (apr_env_get(&remote_ip, "REMOTE_ADDR", r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
+        APR_PALLOC(sockaddr, apr_sockaddr_t *, r->pool, sizeof(apr_sockaddr_t));
+        if (apr_sockaddr_info_get(&sockaddr, "localhost", APR_UNSPEC, 80,
+                                  APR_IPV4_ADDR_OK|APR_IPV6_ADDR_OK, r->pool)
+            != APR_SUCCESS) {
+            THROW(MESSAGE_BUG_FOUND);
         }
 
-        return remote_ip;
+        return sockaddr;
     };
     static const char *get_user_agent(Handle *r)
     {
-        char *agent;
-
-        if (apr_env_get(&agent, "USER_AGENT", r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
-        }
-
-        return agent;
+        return get_env(r->pool, "USER_AGENT");
     };
     static bool is_head_method(Handle *r)
     {
-        char *request_method;
-
-        if (apr_env_get(&request_method, "REQUEST_METHOD",
-                        r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
-        }
-        return (strcmp(request_method, "HEAD") == 0);
+        return (strcmp(get_env(r->pool, "REQUEST_METHOD"), "HEAD") == 0);
     };
     static bool is_post_method(Handle *r)
     {
-        char *request_method;
-
-        if (apr_env_get(&request_method, "REQUEST_METHOD",
-                        r->pool) != APR_SUCCESS) {
-            THROW(MESSAGE_SYS_ENV_VARIABLE_INVALID);
-        }
-        return (strcmp(request_method, "POST") == 0);
+        return (strcmp(get_env(r->pool, "REQUEST_METHOD"), "POST") == 0);
     };
     static int is_meets_condition(Handle *r)
     {
@@ -164,24 +128,38 @@ public:
     };
     static void set_content_type(Handle *r, const char *content_type)
     {
-        cout << "Conten-type: " << content_type << "\r\n\r\n";
+        std::cout << "Content-type: " << content_type << "\r\n";
     };
     static void set_accept_ranges(Handle *r)
     {
-        cout << "Accept-Ranges: bytes\r\n";
+        std::cout << "Accept-Ranges: bytes\r\n";
     }
     static void set_location(Handle *r, const char *uri)
     {
-        cout << "Location: " << uri << "\r\n\r\n";
+        std::cout << "Location: " << uri << "\r\n\r\n";
     };
     static void set_content_disposition(Handle *r, const char *dispos)
     {
-        cout << "Content-Disposition: " << dispos << "\r\n";
+        std::cout << "Content-Disposition: " << dispos << "\r\n";
+    };
+    static void header_end(Handle *r)
+    {
+        std::cout << "\r\n";
     };
     static void set_env(Handle *r, const char *name, const char *value)
     {
         // 何もしない
     };
+    static const char *get_env(apr_pool_t *pool, const char *key)
+    {
+        char *value;
+
+        if (apr_env_get(&value, key, pool) != APR_SUCCESS) {
+            return "";
+        }
+
+        return value;
+    };
 };
 
 #include "CGIResponseWriter.h"
