@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailIterator.h 2296 2006-12-24 02:58:57Z svn $
+ * $Id: ThumbnailIterator.h 2495 2007-07-05 13:53:44Z svn $
  *****************************************************************************/
 
 #ifndef THUMBNAIL_ITERATOR_H
@@ -36,7 +36,7 @@
 
 #include "Uncopyable.h"
 
-
+class UploadItemManager;
 class ThumbnailList;
 
 /**
@@ -49,11 +49,11 @@ public:
      * コンストラクタです．
      *
      * @param[in] pool プール
-     * @param[in] thumbnail_list サムネイルリスト
+     * @param[in] item_manager アイテムマネージャ
      * @param[in] start_index 開始インデックス
      * @param[in] end_index 終了インデックス
      */
-    ThumbnailIterator(apr_pool_t *pool, ThumbnailList *thumbnail_list,
+    ThumbnailIterator(apr_pool_t *pool, UploadItemManager *item_manager,
                       apr_size_t start_index, apr_size_t end_index);
     /**
      * 現在位置のアイテム ID を取得します．
