@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponseWriter.cpp 2511 2007-07-07 06:43:31Z svn $
+ * $Id: ApacheResponseWriter.cpp 2540 2007-07-21 15:21:47Z svn $
  *****************************************************************************/
 
 // Apache の config.h を先に処理させるため，util_filter.h の
@@ -40,29 +40,27 @@
 #include "ApacheResponseWriter.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2511 2007-07-07 06:43:31Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2540 2007-07-21 15:21:47Z svn $");
 
 /******************************************************************************
  * public メソッド
  ****************************************************************************/
 ApacheResponseWriter::ApacheResponseWriter(request_rec *r)
-  : pool_(r->pool),
-    connection_(r->connection),
+  : connection_(r->connection),
     brigade_(apr_brigade_create(r->pool, r->connection->bucket_alloc)),
     filter_(r->output_filters),
     iovec_count_(0)
 {
-
+    pool_ = r->pool;
 }
 
 ApacheResponseWriter::ApacheResponseWriter(ApacheResponseWriter& writer)
-  : pool_(writer.pool_),
-    connection_(writer.connection_),
+  : connection_(writer.connection_),
     brigade_(writer.brigade_),
     filter_(writer.filter_),
     iovec_count_(writer.iovec_count_)
 {
-
+    pool_ = writer.pool_;
 }
 
 ApacheResponseWriter::~ApacheResponseWriter()
