@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2431 2007-05-20 09:38:27Z svn $
+ * $Id: Auxiliary.cpp 2538 2007-07-16 15:21:45Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2431 2007-05-20 09:38:27Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2538 2007-07-16 15:21:45Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -338,18 +338,36 @@ const char *escape_html(apr_pool_t *pool, const char *str)
 
 const char *size_str(apr_pool_t *pool, apr_uint64_t size)
 {
-    if (size < 1024) {
-        return apr_psprintf(pool, "%" APR_UINT64_T_FMT " %s", size, BYTE_UNIT);
-    } else if (size < 1024*1024) {
-        return apr_psprintf(pool, "%.1f %s",
-                            static_cast<double>(size)/1024, KBYTE_UNIT);
-    } else if (size < 1024*1024*1024) {
-        return apr_psprintf(pool, "%.1f %s",
-                            static_cast<double>(size)/(1024*1024), MBYTE_UNIT);
-    } else {
-        return apr_psprintf(pool, "%.1f %s",
-                            static_cast<double>(size)/(1024*1024*1024), GBYTE_UNIT);
-    }
+    static const long int CMP_FACTOR    = 64;
+    long int temp_size;
+    const char *unit_str;
+    ldiv_t size_num;
+
+    do {
+        if (size > (1024*1024*1024)) {
+            temp_size = static_cast<long int>(size / (1024*1024*1024/CMP_FACTOR));
+            unit_str = GBYTE_UNIT;
+            break;
+        }
+
+        temp_size = static_cast<long int>(size / (1024/CMP_FACTOR));
+
+        if (temp_size > (1024 * CMP_FACTOR)) {
+            temp_size /= 1024;
+            unit_str = MBYTE_UNIT;
+        } else if (size > static_cast<apr_size_t>(CMP_FACTOR)) {
+            unit_str = KBYTE_UNIT;
+        } else {
+            temp_size = static_cast<long int>(size * CMP_FACTOR);
+            unit_str = BYTE_UNIT;
+        }
+    } while (0);
+
+    size_num = std::ldiv(temp_size * 10 / CMP_FACTOR, 10L);
+
+    return apr_psprintf(pool,
+                        "%ld.%ld %s",
+                        size_num.quot, size_num.rem, unit_str);
 }
 
 #ifndef HAVE_STRNCHR
