@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemIterator.cpp 2509 2007-07-06 22:48:54Z svn $
+ * $Id: UploadItemIterator.cpp 2548 2007-08-06 14:16:57Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,7 +36,7 @@
 #include "ReadLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemIterator.cpp 2509 2007-07-06 22:48:54Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemIterator.cpp 2548 2007-08-06 14:16:57Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -48,20 +48,19 @@ UploadItemIterator::UploadItemIterator(apr_pool_t *pool,
   : header_list_(NULL),
     curr_index_(0)
 {
-    UploadItemList *item_list;
     ReadLocker manager_locker(item_manager->lock_);
 
-    item_list = item_manager->item_list_;
+    init(pool, item_manager->item_list_, start_index, end_index);
+}
 
-    validate_index(item_list, &start_index, &end_index);
-    size_= end_index - start_index;
-
-    if (size_ != 0) {
-        APR_PALLOC(header_list_, UploadItem::header_t *, pool,
-                   sizeof(UploadItem::header_t)*size_);
-        memcpy(header_list_, item_list->get_by_index(start_index),
-               sizeof(UploadItem::header_t)*size_);
-    }
+UploadItemIterator::UploadItemIterator(apr_pool_t *pool,
+                                       UploadItemList *item_list,
+                                       apr_size_t start_index,
+                                       apr_size_t end_index)
+  : header_list_(NULL),
+    curr_index_(0)
+{
+    init(pool, item_list, start_index, end_index);
 }
 
 UploadItem *UploadItemIterator::get() const
@@ -83,6 +82,20 @@ void UploadItemIterator::reset()
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
+void UploadItemIterator::init(apr_pool_t *pool, UploadItemList *item_list,
+                              apr_size_t start_index, apr_size_t end_index)
+{
+    validate_index(item_list, &start_index, &end_index);
+    size_= end_index - start_index;
+
+    if (size_ != 0) {
+        APR_PALLOC(header_list_, UploadItem::header_t *, pool,
+                   sizeof(UploadItem::header_t)*size_);
+        memcpy(header_list_, item_list->get_by_index(start_index),
+               sizeof(UploadItem::header_t)*size_);
+    }
+}
+
 void UploadItemIterator::validate_index(UploadItemList *item_list,
                                         apr_size_t *start_index,
                                         apr_size_t *end_index)
