@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2507 2007-07-06 19:08:20Z svn $
+ * $Id: uploader_handler.cpp 2542 2007-08-02 16:14:34Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2507 2007-07-06 19:08:20Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2542 2007-08-02 16:14:34Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -715,7 +715,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             ->get_item_file(r->pool, item_id,
                             Response::Writer::is_sendfile_enabled(r));
 
-#ifdef RESPONSE_TYPE_APACHE
+#ifdef UPLOADER_TYPE_APACHE
         {
             const char *item_path;
             apr_file_name_get(&item_path, item_file);
@@ -747,7 +747,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         dispos_encoding = get_dispos_encoding(Response::get_user_agent(r));
 
 #ifdef NUMNAME
-        file_name = apr_psprintf(r->pool, "%s%" APR_SIZE_T_FMT ".%s",
+        file_name = apr_psprintf(r->pool, "%s%5" APR_SIZE_T_FMT ".%s",
                                  NUMNAME, uitem->get_index(),
                                  uitem->get_file_ext());
 #else
