@@ -8,7 +8,7 @@ $VERSION = 0.01;
 use WWW::Mechanize;
 
 use constant LIST_RELEASE_LABEL         => '꡼ե롦ꥹ';
-use constant LIST_RELEASE_LINK_LABEL    => '꡼ե';
+use constant LIST_RELEASE_LINK_LABEL    => '꡼';
 use constant EDIT_RELEASE_LABEL         => '꡼Խ';
 use constant EDIT_RELEASE_LINK_LABEL    => 'ե꡼/ѹ';
 use constant CREATE_RELEASE_LABEL       => '꡼ο';
@@ -33,7 +33,7 @@ sub login {
     my $pass = shift;
 
     $self->{'mech'}->get('https://sourceforge.jp/account/login.php');
-    $self->{'mech'}->form_number(3);
+    $self->{'mech'}->form_number(2);
     $self->{'mech'}->field('form_loginname', $user);
     $self->{'mech'}->field('form_pw', $pass);
     $self->{'mech'}->click();
@@ -60,7 +60,7 @@ sub create_release {
 
     $self->_mv_create_release_page($package);
 
-    $self->{'mech'}->form_number(3);
+    $self->{'mech'}->form_number(2);
     $self->{'mech'}->field('release_name', $version);
     $self->{'mech'}->field('userfile', $file_path);
     $self->{'mech'}->click();
